@@ -1,6 +1,6 @@
 package PDF::API2;
 
-our $VERSION = '2.024'; # VERSION
+our $VERSION = '2.026'; # VERSION
 
 use Carp;
 use Encode qw(:all);
@@ -1174,8 +1174,8 @@ sub openpage {
                 delete $content->{-docompress};
                 $content->{Length}=PDFNum(length($content->{' stream'}));
             }
-            $page->{' fixed'}=1;
         }
+        $page->{' fixed'}=1;
     }
 
     $self->{pdf}->out_obj($page);
@@ -1662,7 +1662,6 @@ sub corefont {
     my ($self,$name,@opts)=@_;
     require PDF::API2::Resource::Font::CoreFont;
     my $obj=PDF::API2::Resource::Font::CoreFont->new_api($self,$name,@opts);
-    $self->resource('Font',$obj->name,$obj);
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if($opts{-unicodemap}==1);
     return($obj);
@@ -1713,8 +1712,6 @@ sub psfont {
     require PDF::API2::Resource::Font::Postscript;
     my $obj=PDF::API2::Resource::Font::Postscript->new_api($self,$psf,%opts);
 
-    $self->resource('Font',$obj->name,$obj,$self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if($opts{-unicodemap}==1);
     return($obj);
@@ -1766,8 +1763,6 @@ sub ttfont {
     require PDF::API2::Resource::CIDFont::TrueType;
     my $obj = PDF::API2::Resource::CIDFont::TrueType->new_api($self, $file, %opts);
 
-    $self->resource('Font', $obj->name, $obj, $self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if $opts{-unicodemap};
     return $obj;
@@ -1802,8 +1797,6 @@ sub cjkfont {
     require PDF::API2::Resource::CIDFont::CJKFont;
     my $obj=PDF::API2::Resource::CIDFont::CJKFont->new_api($self,$name,%opts);
 
-    $self->resource('Font',$obj->name,$obj,$self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if($opts{-unicodemap}==1);
     return($obj);
@@ -1852,8 +1845,6 @@ sub synfont {
     require PDF::API2::Resource::Font::SynFont;
     my $obj=PDF::API2::Resource::Font::SynFont->new_api($self,@opts);
 
-    $self->resource('Font',$obj->name,$obj,$self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if($opts{-unicodemap}==1);
     return($obj);
@@ -1873,8 +1864,6 @@ sub bdfont {
     require PDF::API2::Resource::Font::BdFont;
     my $obj=PDF::API2::Resource::Font::BdFont->new_api($self,@opts);
 
-    $self->resource('Font',$obj->name,$obj,$self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     ## $obj->tounicodemap; # does not support unicode!
     return($obj);
@@ -1927,8 +1916,6 @@ sub image_jpeg {
     require PDF::API2::Resource::XObject::Image::JPEG;
     my $obj=PDF::API2::Resource::XObject::Image::JPEG->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -1945,8 +1932,6 @@ sub image_tiff {
     require PDF::API2::Resource::XObject::Image::TIFF;
     my $obj=PDF::API2::Resource::XObject::Image::TIFF->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -1963,8 +1948,6 @@ sub image_pnm {
     require PDF::API2::Resource::XObject::Image::PNM;
     my $obj=PDF::API2::Resource::XObject::Image::PNM->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -1981,8 +1964,6 @@ sub image_png {
     require PDF::API2::Resource::XObject::Image::PNG;
     my $obj=PDF::API2::Resource::XObject::Image::PNG->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -1999,8 +1980,6 @@ sub image_gif {
     require PDF::API2::Resource::XObject::Image::GIF;
     my $obj=PDF::API2::Resource::XObject::Image::GIF->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2019,8 +1998,6 @@ sub image_gd {
     require PDF::API2::Resource::XObject::Image::GD;
     my $obj=PDF::API2::Resource::XObject::Image::GD->new_api($self,$gd,undef,%opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2046,8 +2023,6 @@ sub colorspace_act {
     require PDF::API2::Resource::ColorSpace::Indexed::ACTFile;
     my $obj=PDF::API2::Resource::ColorSpace::Indexed::ACTFile->new_api($self,$file);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2064,8 +2039,6 @@ sub colorspace_web {
     require PDF::API2::Resource::ColorSpace::Indexed::WebColor;
     my $obj=PDF::API2::Resource::ColorSpace::Indexed::WebColor->new_api($self);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2084,8 +2057,6 @@ sub colorspace_hue {
     require PDF::API2::Resource::ColorSpace::Indexed::Hue;
     my $obj=PDF::API2::Resource::ColorSpace::Indexed::Hue->new_api($self);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2112,8 +2083,6 @@ sub colorspace_separation {
     require PDF::API2::Resource::ColorSpace::Separation;
     my $obj=PDF::API2::Resource::ColorSpace::Separation->new_api($self,$name,@clr);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2145,8 +2114,6 @@ sub colorspace_devicen {
     require PDF::API2::Resource::ColorSpace::DeviceN;
     my $obj=PDF::API2::Resource::ColorSpace::DeviceN->new_api($self,$clrs,$samples);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2177,8 +2144,6 @@ sub xo_code128 {
     require PDF::API2::Resource::XObject::Form::BarCode::code128;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::code128->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2189,8 +2154,6 @@ sub xo_codabar {
     require PDF::API2::Resource::XObject::Form::BarCode::codabar;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::codabar->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2201,8 +2164,6 @@ sub xo_2of5int {
     require PDF::API2::Resource::XObject::Form::BarCode::int2of5;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::int2of5->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2213,8 +2174,6 @@ sub xo_3of9 {
     require PDF::API2::Resource::XObject::Form::BarCode::code3of9;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::code3of9->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2225,8 +2184,6 @@ sub xo_ean13 {
     require PDF::API2::Resource::XObject::Form::BarCode::ean13;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::ean13->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2248,8 +2205,6 @@ sub xo_form {
 
     my $obj=PDF::API2::Resource::XObject::Form::Hybrid->new_api($self);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2265,8 +2220,6 @@ sub egstate {
 
     my $obj=PDF::API2::Resource::ExtGState->new_api($self,pdfkey());
 
-    $self->resource('ExtGState',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2282,8 +2235,6 @@ sub pattern {
 
     my $obj=PDF::API2::Resource::Pattern->new_api($self,undef,%opts);
 
-    $self->resource('Pattern',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2299,8 +2250,6 @@ sub shading {
 
     my $obj=PDF::API2::Resource::Shading->new_api($self,undef,%opts);
 
-    $self->resource('Shading',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2362,85 +2311,14 @@ sub named_destination
 
 =back
 
-=head1 RESOURCE METHODS
-
-=over
-
-=item $pdf->resource($type, $key, $obj, $force)
-
-Adds a resource to the global PDF tree.
-
-B<Example:>
-
-    $pdf->resource('Font', $fontkey, $fontobj);
-    $pdf->resource('XObject', $imagekey, $imageobj);
-    $pdf->resource('Shading', $shadekey, $shadeobj);
-    $pdf->resource('ColorSpace', $spacekey, $speceobj);
-
-B<Note:> You only have to add the required resources if they are NOT
-handled by the font, image, shade or space methods.
-
-=cut
-
-sub resource 
-{
-    return(undef);
-    my ($self, $type, $key, $obj, $force) = @_;
-
-    $self->{pages}->{Resources}||=PDFDict();
-
-    my $dict=$self->{pages}->{Resources};
-    $dict->realise if(ref($dict)=~/Objind$/);
-
-    $self->{pdf}->new_obj($dict) unless($dict->is_obj($self->{pdf}));
-
-    $dict->{$type}=$dict->{$type} || PDFDict();
-    $dict->{$type}->realise if(ref($dict->{$type})=~/Objind$/);
-
-    if(defined($obj)) 
-    {
-        if($force) 
-        {
-            $dict->{$type}->{$key}=$obj;
-        } 
-        else 
-        {
-            $dict->{$type}->{$key}=$dict->{$type}->{$key} || $obj;
-        }
-
-        $self->{pdf}->out_obj($dict)
-            if($dict->is_obj($self->{pdf}));
-
-        $self->{pdf}->out_obj($dict->{$type})
-            if($dict->{$type}->is_obj($self->{pdf}));
-
-        $self->{pdf}->out_obj($obj)
-            if($obj->is_obj($self->{pdf}));
-
-        $self->{pdf}->out_obj($self->{pages});
-
-        return($dict);
-    }
-    return($dict->{$type}->{$key} || undef);
-}
-
 1;
 
 __END__
 
-=back
-
 =head1 KNOWN ISSUES
 
 This module does not work with perl's -l command-line switch.
 
-PDFs using cross-reference streams instead of cross-reference tables
-are not yet supported.  Cross-reference streams were added as an
-option in version 1.5 of the PDF spec, but were only used infrequently
-until Adobe Acrobat 9 started using them by default.  A patch would be
-welcome -- see the PDF 1.7 specification, sections 7.5.4 and 7.5.8 for
-implementation details.
-
 =head1 AUTHOR
 
 PDF::API2 was originally written by Alfred Reibenschuh.
