@@ -1,14 +1,16 @@
 package PDF::API2::Basic::PDF::Filter::LZWDecode;
 
-our $VERSION = '2.024'; # VERSION
+our $VERSION = '2.026'; # VERSION
 
 use base 'PDF::API2::Basic::PDF::Filter::FlateDecode';
 
 no warnings qw[ deprecated recursion uninitialized ];
 
 sub new {
-    my $class = shift();
-    my $self = {};
+    my ($class, $decode_parms) = @_;
+    my $self = {
+        DecodeParms => $decode_parms,
+    };
 
     $self->{'table'} = [map { pack('C', $_) } (0 .. 255, 0, 0)];
     $self->{'initial_code_length'} = 9;
@@ -23,11 +25,24 @@ sub new {
 
 sub infilt {
     my ($self, $data, $is_last) = @_;
-    my ($code, $partial_code, $partial_bits, $result);
+    my ($code, $result);
+    my $partial_code = $self->{'partial_code'};
+    my $partial_bits = $self->{'partial_bits'};
 
-    while ($data ne '' or $partial_bits) {
+    my $early_change = 1;
+    if ($self->{'DecodeParms'} and $self->{'DecodeParms'}->{'EarlyChange'}) {
+        $early_change = $self->{'DecodeParms'}->{'EarlyChange'}->val();
+    }
+
+    while ($data ne '') {
         ($code, $partial_code, $partial_bits) = $self->read_dat(\$data, $partial_code, $partial_bits, $self->{'code_length'});
-        $self->{'code_length'}++ if $self->{'next_code'} == (1 << $self->{'code_length'});
+        last unless defined $code;
+
+        unless ($early_change) {
+            if ($self->{'next_code'} == (1 << $self->{'code_length'}) and $self->{'code_length'} < 12) {
+                $self->{'code_length'}++;
+            }
+        }
 
         if ($code == $self->{'clear_table'}) {
             $self->{'code_length'} = $self->{'initial_code_length'};
@@ -48,7 +63,15 @@ sub infilt {
             $result .= $self->{'table'}[$self->{'next_code'}];
             $self->{'next_code'}++;
         }
+
+        if ($early_change) {
+            if ($self->{'next_code'} == (1 << $self->{'code_length'}) and $self->{'code_length'} < 12) {
+                $self->{'code_length'}++;
+            }
+        }
     }
+    $self->{'partial_code'} = $partial_code;
+    $self->{'partial_bits'} = $partial_bits;
     return $result;
 }
 
@@ -57,6 +80,7 @@ sub read_dat {
     $partial_bits = 0 unless defined $partial_bits;
 
     while ($partial_bits < $code_length) {
+        return (undef, $partial_code, $partial_bits) unless length($$data_ref);
         $partial_code = ($partial_code << 8) + unpack('C', $$data_ref);
         substr($$data_ref, 0, 1) = '';
         $partial_bits += 8;
