@@ -1,6 +1,6 @@
 package PDF::API2::Content;
 
-our $VERSION = '2.024'; # VERSION
+our $VERSION = '2.026'; # VERSION
 
 use base 'PDF::API2::Basic::PDF::Dict';
 
@@ -44,7 +44,7 @@ sub new {
     $self->{' fontset'}=0;
     $self->{' fontsize'}=0;
     $self->{' charspace'}=0;
-    $self->{' hspace'}=100;
+    $self->{' hscale'}=100;
     $self->{' wordspace'}=0;
     $self->{' lead'}=0;
     $self->{' rise'}=0;
@@ -66,7 +66,7 @@ sub outobjdeep {
     my $self = shift @_;
     $self->textend;
     foreach my $k (qw[ api apipdf apiistext apipage font fontset fontsize 
-                       charspace hspace wordspace lead rise render matrix
+                       charspace hscale wordspace lead rise render matrix
                        textmatrix textlinematrix fillcolor strokecolor
                        translate scale skew rotate ]) {
         $self->{" $k"}=undef;
@@ -463,61 +463,73 @@ sub linejoin {
     $this->add(_linejoin($linejoin));
 }
 
-=item $content->meterlimit($ratio)
+=item $content->miterlimit($ratio)
 
-Note: This method is named incorrectly, and will be renamed in a
-future release.
+Sets the miter limit when the line join style is a miter join.
 
-Sets the miter (not meter) limit when the line join style is a miter
-join.
+The C<$ratio> is the maximum length of the miter (inner to outer
+corner) divided by the line width. Any miter above this ratio will be
+converted to a bevel join. The practical effect is that lines meeting
+at shallow angles are chopped off instead of producing long pointed
+corners.
 
-The ratio is the maximum length of the miter divided by the line
-width.  Any miter above this ratio will be converted to a bevel join.
+There is no documented default miter limit.
 
 =cut
 
-sub _meterlimit {
-    my ($limit)=@_;
+sub miterlimit {
+    my ($self, $limit) = @_;
+    $self->add(_miterlimit($limit));
+}
+
+sub _miterlimit {
+    my ($limit) = @_;
     return ($limit, 'M');
 }
-sub meterlimit {
-    my ($this, $limit)=@_;
-    $this->add(_meterlimit($limit));
-}
+
+# Deprecated: miterlimit was originally named incorrectly
+sub  meterlimit { return  miterlimit(@_) }
+sub _meterlimit { return _miterlimit(@_) }
 
 =item $content->linedash()
 
 =item $content->linedash($length)
 
-=item $content->linedash($on, $off)
+=item $content->linedash($dash_length, $gap_length, ...)
+
+=item $content->linedash(-pattern => [$dash_length, $gap_length, ...], -shift => $offset)
 
 Sets the line dash pattern.
 
-If passed without any arguments, a solid line will be drawn.
+If called without any arguments, a solid line will be drawn.
 
-If passed with one argument, the strokes and spaces will have equal
+If called with one argument, the dashes and gaps will have equal
 lengths.
 
-If passed with two arguments, the strokes will have length C<$on>, and
-the spaces will have length C<$off>.
+If called with two or more arguments, the arguments represent
+alternating dash and gap lengths.
+
+If called with a hash of arguments, a dash phase may be set, which
+specifies the distance into the pattern at which to start the dash.
 
 =cut
 
 sub _linedash {
-    my (@a)=@_;
-    if (scalar @a < 1) {
-        return ('[',']','0','d');
+    my @a = @_;
+    unless (scalar @a) {
+        return ('[', ']', '0', 'd');
     } 
     else {
-        if ($a[0]=~/^\-/) {
-            # Note: This is undocumented, and will probably go away in
-            # the future.
-            my %a=@a;
-            $a{-pattern}=[$a{-full}||0,$a{-clear}||0] unless(ref $a{-pattern});
-            return ('[',floats(@{$a{-pattern}}),']',($a{-shift}||0),'d');
+        if ($a[0] =~ /^\-/) {
+            my %a = @a;
+
+            # Deprecated: the -full and -clear options will be removed in a future release
+            $a{'-pattern'} = [$a{'-full'} || 0, $a{'-clear'} || 0] unless exists $a{'-pattern'};
+
+            return ('[', floats(@{$a{'-pattern'}}), ']', ($a{'-shift'} || 0), 'd');
         } 
         else {
-            return ('[',floats(@a),'] 0 d');
+            return ('[', floats(@a), '] 0 d');
         }
     }
 }
@@ -1359,29 +1371,32 @@ sub wordspace {
     return $self->{' wordspace'};
 }
 
-=item $scale = $content->hspace($scale)
+=item $scale = $content->hscale($scale)
 
-Note: This method is named incorrectly, and will be renamed in a
-future release.
-
-Sets the percentage of horizontal text scaling (not spacing).  This is
-initially 100 (i.e. no scaling), and must be passed as an integer.
+Sets and returns the percentage of horizontal text scaling.  Enter a
+scale greater than 100 to stretch text, less than 100 to squeeze
+text, or 100 to disable any existing scaling.
 
 =cut
 
-sub _hspace {
-    my ($para) = @_;
-    return float($para, 6) . ' Tz';
+sub _hscale {
+    my ($scale) = @_;
+    return float($scale, 6) . ' Tz';
 }
-sub hspace {
-    my ($self,$para)=@_;
-    if (defined $para) {
-        $self->{' hspace'}=$para;
-        $self->add(_hspace($para));
+
+sub hscale {
+    my ($self, $scale) = @_;
+    if (defined $scale) {
+        $self->{' hscale'} = $scale;
+        $self->add(_hscale($scale));
     }
-    return $self->{' hspace'};
+    return $self->{' hscale'};
 }
 
+# Deprecated: hscale was originally named incorrectly (as hspace)
+sub  hspace { return  hscale(@_) }
+sub _hspace { return _hscale(@_) }
+
 =item $leading = $content->lead($leading)
 
 Sets the text leading, which is the distance between baselines.  This
@@ -1483,7 +1498,7 @@ sub textstate {
     my %state;
     if (scalar @_) {
         %state = @_;
-        foreach my $k (qw( charspace hspace wordspace lead rise render )) {
+        foreach my $k (qw( charspace hscale wordspace lead rise render )) {
             next unless($state{$k});
             $self->can($k)->($self, $state{$k});
         }
@@ -1506,7 +1521,7 @@ sub textstate {
         %state = ();
     } 
     else {
-        foreach my $k (qw( font fontsize charspace hspace wordspace lead rise render )) {
+        foreach my $k (qw( font fontsize charspace hscale wordspace lead rise render )) {
             $state{$k}=$self->{" $k"};
         }
         $state{matrix}=[@{$self->{" matrix"}}];
@@ -1594,42 +1609,47 @@ sub distance {
     $self->{' textlinematrix'}->[0]=$dx;
 }
 
+=item $content->cr()
+
 =item $content->cr($vertical_offset)
 
-If passed with an argument, moves to the start of the next line,
-offset by the given value.
+Moves the cursor to the start of the line when called without an
+argument.  If leading has been set, the cursor will move to the next
+line instead.
 
-If passed without an argument, moves to the start of the next line.
+An offset can be passed as an argument to override the leading value.
+A positive offset will move the cursor up, and a negative offset will
+move the cursor down.
 
-Note that this is equivalent to a carriage return plus line feed.  To
-get just a carriage return, pass zero as the argument.
+Pass zero as the argument to ignore the leading and get just a
+carriage return.
 
 =cut
 
 sub cr {
-    my ($self, $para) = @_;
-    if (defined($para)) {
-        $self->add(0,float($para),'Td');
-        $self->matrix_update(0,$para);
+    my ($self, $offset) = @_;
+    if (defined $offset) {
+        $self->add(0, float($offset), 'Td');
+        $self->matrix_update(0, $offset);
     }
     else {
         $self->add('T*');
-        $self->matrix_update(0,$self->lead);
+        $self->matrix_update(0, $self->lead() * -1);
     }
-    $self->{' textlinematrix'}->[0]=0;
+    $self->{' textlinematrix'}->[0] = 0;
 }
 
-=item $content->nl
+=item $content->nl()
 
 Moves to the start of the next line.
 
 =cut
 
 sub nl {
-    my ($self, $width) = @_;
+    my $self = shift();
     $self->add('T*');
-    $self->matrix_update(-($width||0),-$self->lead);
-    $self->{' textlinematrix'}->[0]=0;
+    $self->matrix_update(0, $self->lead() * -1);
+    $self->{' textlinematrix'}->[0] = 0;
 }
 
 =item ($tx, $ty) = $content->textpos()
@@ -1761,8 +1781,8 @@ sub text {
 
     if (defined $opt{-indent}) {
     # changed fot acrobat 8 and possible others
-    #    $self->add('[',(-$opt{-indent}*(1000/$self->{' fontsize'})*(100/$self->hspace)),']','TJ');
-        $self->add($self->{' font'}->text($text, $self->{' fontsize'}, (-$opt{-indent}*(1000/$self->{' fontsize'})*(100/$self->hspace))));
+    #    $self->add('[',(-$opt{-indent}*(1000/$self->{' fontsize'})*(100/$self->hscale())),']','TJ');
+        $self->add($self->{' font'}->text($text, $self->{' fontsize'}, (-$opt{-indent}*(1000/$self->{' fontsize'})*(100/$self->hscale()))));
     }
     else {
         $self->add($self->{' font'}->text($text,$self->{' fontsize'}));
@@ -1815,7 +1835,7 @@ sub advancewidth {
     my ($self,$text,@opts) = @_;
     if(scalar @opts > 1) {
         my %opts=@opts;
-        foreach my $k (qw[ font fontsize wordspace charspace hspace]) {
+        foreach my $k (qw[ font fontsize wordspace charspace hscale]) {
             $opts{$k}=$self->{" $k"} unless(defined $opts{$k});
         }
         my $glyph_width = $opts{font}->width($text)*$opts{fontsize};
@@ -1823,7 +1843,7 @@ sub advancewidth {
         my $num_char = length($text);
         my $word_spaces = $opts{wordspace}*$num_space;
         my $char_spaces = $opts{charspace}*$num_char;
-        my $advance = ($glyph_width+$word_spaces+$char_spaces)*$opts{hspace}/100;
+        my $advance = ($glyph_width+$word_spaces+$char_spaces)*$opts{hscale}/100;
         return $advance;
     }
     else {
@@ -1832,7 +1852,7 @@ sub advancewidth {
         my $num_char = length($text);
         my $word_spaces = $self->wordspace*$num_space;
         my $char_spaces = $self->charspace*$num_char;
-        my $advance = ($glyph_width+$word_spaces+$char_spaces)*$self->hspace/100;
+        my $advance = ($glyph_width+$word_spaces+$char_spaces)*$self->hscale()/100;
         return $advance;
     }
 }
@@ -1843,10 +1863,10 @@ sub advancewidth {
 
 sub text_justified {
     my ($self,$text,$width,%opts) = @_;
-    my $hs = $self->hspace;
-    $self->hspace($hs*($width/$self->advancewidth($text)));
+    my $hs = $self->hscale();
+    $self->hscale($hs*($width/$self->advancewidth($text)));
     $self->text($text,%opts);
-    $self->hspace($hs);
+    $self->hscale($hs);
     return $width;
 }
 
@@ -1896,13 +1916,13 @@ sub text_fill_justified {
     my ($self,$text,$width,%opts) = @_;
     my $over=(not(defined($opts{-spillover}) and $opts{-spillover} == 0));
     my ($line,$ret)=$self->_text_fill_line($text,$width,$over);
-    my $hs=$self->hspace;
+    my $hs=$self->hscale();
     my $w=$self->advancewidth($line);
     if ($ret||$w>=$width) {
-        $self->hspace($hs*($width/$w));
+        $self->hscale($hs*($width/$w));
     }
     $width=$self->text($line,%opts);
-    $self->hspace($hs);
+    $self->hscale($hs);
     return($width,$ret);
 }
 
@@ -2025,7 +2045,7 @@ sub textlabel {
     $self->font($font,$size);
 
     $self->charspace($opts{-charspace})     if($opts{-charspace});
-    $self->hspace($opts{-hspace})           if($opts{-hspace});
+    $self->hscale($opts{-hscale})           if($opts{-hscale});
     $self->wordspace($opts{-wordspace})     if($opts{-wordspace});
     $self->render($opts{-render})           if($opts{-render});
 
@@ -2136,7 +2156,7 @@ sub textstart {
         $self->{' fontset'}=0;
         $self->{' fontsize'}=0;
         $self->{' charspace'}=0;
-        $self->{' hspace'}=100;
+        $self->{' hscale'}=100;
         $self->{' wordspace'}=0;
         $self->{' lead'}=0;
         $self->{' rise'}=0;
