@@ -1,6 +1,6 @@
 package PDF::API2::Resource::CIDFont::TrueType::FontFile;
 
-our $VERSION = '2.024'; # VERSION
+our $VERSION = '2.026'; # VERSION
 
 use base 'PDF::API2::Basic::PDF::Dict';
 
@@ -435,7 +435,7 @@ sub new {
 	$data->{noembed} = $opts{-noembed}==1 ? 1 : 0;
     $data->{iscff} = (defined $font->{'CFF '}) ? 1 : 0;
 
-    $self->{Subtype}=PDFName('Type1C') if($data->{iscff});
+    $self->{Subtype}=PDFName('CIDFontType0C') if($data->{iscff});
 
     $data->{fontfamily}=$font->{'name'}->read->find_name(1);
     $data->{fontname}=$font->{'name'}->read->find_name(4);
