@@ -1,6 +1,6 @@
 package PDF::API2::Resource::ExtGState;
 
-our $VERSION = '2.024'; # VERSION
+our $VERSION = '2.026'; # VERSION
 
 use base 'PDF::API2::Resource';
 
@@ -216,16 +216,19 @@ sub linejoin {
     return($self);
 }
 
-=item $egs->meterlimit $limit
+=item $egs->miterlimit $limit
 
 =cut
 
-sub meterlimit {
+sub miterlimit {
     my ($self,$var)=@_;
     $self->{ML}=PDFNum($var);
     return($self);
 }
 
+# Deprecated: miterlimit was originally named incorrectly
+sub meterlimit { return miterlimit(@_) }
+
 =item $egs->dash @dash
 
 =cut
