@@ -1,6 +1,6 @@
 package PDF::API2::Util;
 
-our $VERSION = '2.024'; # VERSION
+our $VERSION = '2.026'; # VERSION
 
 no warnings qw[ recursion uninitialized ];
 
@@ -672,36 +672,8 @@ PDF::API2::Util - utility package for often use methods across the package.
 
 =item %sizes = getPaperSizes();
 
-Will retrieve the registered paper sizes of PDF::API2.
-
-    print Dumper(\%sizes);
-    $VAR1={
-        '4a'         =>  [ 4760  , 6716  ],
-        '2a'         =>  [ 3368  , 4760  ],
-        'a0'         =>  [ 2380  , 3368  ],
-        'a1'         =>  [ 1684  , 2380  ],
-        'a2'         =>  [ 1190  , 1684  ],
-        'a3'         =>  [ 842   , 1190  ],
-        'a4'         =>  [ 595   , 842   ],
-        'a5'         =>  [ 421   , 595   ],
-        'a6'         =>  [ 297   , 421   ],
-        '4b'         =>  [ 5656  , 8000  ],
-        '2b'         =>  [ 4000  , 5656  ],
-        'b0'         =>  [ 2828  , 4000  ],
-        'b1'         =>  [ 2000  , 2828  ],
-        'b2'         =>  [ 1414  , 2000  ],
-        'b3'         =>  [ 1000  , 1414  ],
-        'b4'         =>  [ 707   , 1000  ],
-        'b5'         =>  [ 500   , 707   ],
-        'b6'         =>  [ 353   , 500   ],
-        'letter'     =>  [ 612   , 792   ],
-        'broadsheet' =>  [ 1296  , 1584  ],
-        'ledger'     =>  [ 1224  , 792   ],
-        'tabloid'    =>  [ 792   , 1224  ],
-        'legal'      =>  [ 612   , 1008  ],
-        'executive'  =>  [ 522   , 756   ],
-        '36x36'      =>  [ 2592  , 2592  ],
-    };
+Returns a hash containing the available paper size aliases as keys and
+their dimensions as a two-element array reference.
 
 =back
 
